@@ -79,10 +79,10 @@ class MPRester:
 
     def __init__(
         self,
-        api_key=DEFAULT_API_KEY,
-        endpoint=DEFAULT_ENDPOINT,
-        notify_db_version=False,
-        include_user_agent=True,
+        api_key: str = DEFAULT_API_KEY,
+        endpoint: str = DEFAULT_ENDPOINT,
+        notify_db_version: bool = False,
+        include_user_agent: bool = True,
         monty_decode: bool = True,
         use_document_model: bool = True,
         session: Session = None,
@@ -121,9 +121,9 @@ class MPRester:
             headers (dict): Custom headers for localhost connections.
         """
 
-        if api_key and len(api_key) == 16:
+        if api_key and len(api_key) != 32:
             raise ValueError(
-                "Please use a new API key from https://next-gen.materialsproject.org/api "
+                "Please use a new API key from https://materialsproject.org/api "
                 "Keys for the new API are 32 characters, whereas keys for the legacy "
                 "API are 16 characters."
             )
@@ -706,17 +706,11 @@ class MPRester:
                 'reference': 'H. E. Barner and R. V. Scheuerman, Handbook of thermochemical data for
                 compounds and aqueous species, Wiley, New York (1978)'}}
         """
-
-        ion_data = [
-            d
-            for d in self.contribs.contributions.get_entries(
-                project="ion_ref_data",
-                fields=["identifier", "formula", "data"],
-                per_page=500,
-            ).result()["data"]
-        ]
-
-        return ion_data
+        return self.contribs.query_contributions(
+            query={"project": "ion_ref_data"},
+            fields=["identifier", "formula", "data"],
+            paginate=True
+        ).get("data")
 
     def get_ion_reference_data_for_chemsys(self, chemsys: Union[str, List]) -> List[Dict]:
         """
